%global with_debug 1

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package %{nil}
%endif

# Golang minor version
%if 0%{?rhel} && ! 0%{?fedora}
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%endif

%global provider github
%global provider_tld com
%global project cri-o
%global repo cri-o
# https://github.com/cri-o/cri-o
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}
%global git0 https://%{import_path}
%global commit0 6b97f815cfbdf680a7ddf2435291fb7e49776ef1
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})

%global service_name crio

Name: %{repo}
Version: 1.17.5
Release: 7.rhaos4.4.git%{shortcommit0}%{?dist}
Summary: Kubernetes Container Runtime Interface for OCI-based containers
License: ASL 2.0
URL: %{git0}
Source0: %{git0}/archive/%{commit0}/%{name}-%{shortcommit0}.tar.gz
Source1: seccomp.json
Source3: %{service_name}-network.sysconfig
Source4: %{service_name}-storage.sysconfig
Source5: %{service_name}-metrics.sysconfig
Source6: %{service_name}.service
BuildRequires: golang
BuildRequires: git
BuildRequires: glib2-devel
BuildRequires: glibc-static
BuildRequires: go-md2man
BuildRequires: gpgme-devel
BuildRequires: libassuan-devel
BuildRequires: libseccomp-devel
BuildRequires: pkgconfig(systemd)
Requires(pre): container-selinux
Requires: skopeo-containers >= 1:0.1.40-1
Requires: runc >= 1.0.0-61.rc8
Obsoletes: ocid <= 0.3
Provides: ocid = %{version}-%{release}
Provides: %{service_name} = %{version}-%{release}
Requires: containernetworking-plugins >= 0.8.2-3
Requires: conmon >= 2.0.2-2

%description
%{summary}

%prep
%autosetup -Sgit -n %{name}-%{commit0}
cp %{SOURCE6} contrib/systemd/.
sed -i 's/install.config: crio.conf/install.config:/' Makefile
sed -i 's/install.bin: binaries/install.bin:/' Makefile
sed -i 's/install.man: $(MANPAGES)/install.man:/' Makefile
sed -i 's/\.gopathok //' Makefile
sed -i 's/%{version}/%{version}-%{release}/' internal/version/version.go
sed -i 's/\/local//' contrib/systemd/%{service_name}.service
sed -i 's/\/local//' contrib/systemd/%{service_name}-wipe.service

%build
mkdir _output
pushd _output
mkdir -p src/%{provider}.%{provider_tld}/{%{project},opencontainers}
ln -s $(dirs +1 -l) src/%{import_path}
popd

ln -s vendor src
export GOPATH=$(pwd)/_output:$(pwd)
export BUILDTAGS="selinux seccomp exclude_graphdriver_devicemapper exclude_graphdriver_btrfs containers_image_ostree_stub"
export GO111MODULE=off
# build crio
%gobuild -o bin/%{service_name} %{import_path}/cmd/%{service_name}

# build crio-status
%gobuild -o bin/crio-status %{import_path}/cmd/crio-status

# build pinns and docs
%{__make} bin/pinns
%if 0%{?rhel} && ! 0%{?fedora}
GO_MD2MAN=go-md2man GO="scl enable go-toolset-1.12 -- go" %{__make} docs
%else
GO_MD2MAN=go-md2man %{__make} docs
%endif

%install
./bin/%{service_name} \
      --selinux \
      --cgroup-manager "systemd" \
      --storage-driver "overlay" \
      --conmon "%{_libexecdir}/crio/conmon" \
      --cni-plugin-dir "%{_libexecdir}/cni" \
      --default-mounts "%{_datadir}/rhel/secrets:/run/secrets" \
      --storage-opt "overlay.override_kernel_check=1" \
      config > %{service_name}.conf

# install conf files
install -dp %{buildroot}%{_sysconfdir}/cni/net.d
install -p -m 644 contrib/cni/10-crio-bridge.conf %{buildroot}%{_sysconfdir}/cni/net.d/100-crio-bridge.conf
install -p -m 644 contrib/cni/99-loopback.conf %{buildroot}%{_sysconfdir}/cni/net.d/200-loopback.conf

install -dp %{buildroot}%{_sysconfdir}/sysconfig
#install -p -m 644 contrib/sysconfig/%%{service_name} %%{buildroot}%%{_sysconfdir}/sysconfig/%%{service_name}
install -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-network
install -p -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-storage
install -p -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-metrics

make PREFIX=%{buildroot}%{_usr} DESTDIR=%{buildroot} \
            install.bin \
            install.completions \
            install.config \
            install.man \
            install.systemd

# install seccomp.json
install -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{service_name}/seccomp.json

install -dp %{buildroot}%{_sharedstatedir}/containers
install -dp %{buildroot}%{_sharedstatedir}/cni/bin
install -dp %{buildroot}%{_sysconfdir}/kubernetes/cni/net.d
install -dp %{buildroot}%{_datadir}/containers/oci/hooks.d
install -dp %{buildroot}/opt/cni/bin

%check
%if 0%{?with_check}
export GOPATH=%{buildroot}/%{gopath}:$(pwd)/Godeps/_workspace:%{gopath}
%endif

%post
%systemd_post %{service_name}

%preun
%systemd_preun %{service_name}

%postun
%systemd_postun_with_restart %{service_name}

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{service_name}
%{_bindir}/%{service_name}-status
%{_bindir}/pinns
%{_mandir}/man5/%{service_name}.conf.5*
%{_mandir}/man8/%{service_name}*.8*
%dir %{_sysconfdir}/%{service_name}
%config(noreplace) %{_sysconfdir}/%{service_name}/%{service_name}.conf
%config(noreplace) %{_sysconfdir}/%{service_name}/seccomp.json
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-storage
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-network
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-metrics
%config(noreplace) %{_sysconfdir}/cni/net.d/100-%{service_name}-bridge.conf
%config(noreplace) %{_sysconfdir}/cni/net.d/200-loopback.conf
%config(noreplace) %{_sysconfdir}/crictl.yaml
%{_unitdir}/%{service_name}.service
%{_unitdir}/%{name}.service
%{_unitdir}/%{service_name}-shutdown.service
%{_unitdir}/%{service_name}-wipe.service
%dir %{_sharedstatedir}/containers
%dir %{_sharedstatedir}/cni
%dir %{_sharedstatedir}/cni/bin
%dir %{_sysconfdir}/kubernetes
%dir %{_sysconfdir}/kubernetes/cni
%dir %{_sysconfdir}/kubernetes/cni/net.d
%dir %{_datadir}/containers
%dir %{_datadir}/containers/oci
%dir %{_datadir}/containers/oci/hooks.d
%dir /opt/cni
%dir /opt/cni/bin
%dir %{_datadir}/oci-umount
%dir %{_datadir}/oci-umount/oci-umount.d
%{_datadir}/oci-umount/oci-umount.d/%{service_name}-umount.conf
%{_datadir}/bash-completion/completions/%{service_name}*
%{_datadir}/fish/completions/%{service_name}*.fish
%{_datadir}/zsh/site-functions/_%{service_name}*

%changelog
* Wed Sep 09 2020 Peter Hunt <pehunt@redhat.com> - 1.17.5-7.rhaos4.4.git6b97f81
- Bump to newer version than previously build

* Tue Sep 01 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.17.5-3.rhaos4.4.git6b97f81
- autobuilt 6b97f81

* Sun Aug 30 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.17.5-2.rhaos4.4.git7f0085b
- bump to 1.17.5
- autobuilt 7f0085b

* Sun Aug 30 2020 Peter Hunt (Bot) <pehunt+bot@redhat.com>
- bump to 1.15.1
- autobuilt 

* Mon Aug 24 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.5-4.rhaos4.4.git7f0085b
- autobuilt 7f0085b

* Fri Aug 21 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.5-3.rhaos4.4.git75b5183
- autobuilt 75b5183

* Tue Aug 18 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.5-2.rhaos4.4.git34a1ed2
- bump to 1.17.5
- autobuilt 34a1ed2

* Tue Aug 18 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-25.rhaos4.4.git462bd29
- autobuilt 462bd29

* Mon Aug 10 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-24.rhaos4.4.git73658e6
- autobuilt 73658e6

* Wed Jul 29 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-23.rhaos4.4.git93e6ee4
- autobuilt 93e6ee4

* Tue Jul 28 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-22.rhaos4.4.git5addc1e
- autobuilt 5addc1e

* Tue Jul 21 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-21.rhaos4.4.git7854af4
- autobuilt 7854af4

* Fri Jul 17 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-20.rhaos4.4.git7c01831
- autobuilt 7c01831

* Mon Jul 06 2020 Lokesh Mandvekar <lsm5@redhat.com> - 1.17.4-19.rhaos4.4.gitfb8131a
- bump release tag

* Thu Jul 02 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-2.rhaos4.4.gitfb8131a
- bump to 1.17.4
- autobuilt fb8131a

* Sat Jun 27 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-2.rhaos4.4.gitfb8131a
- bump to 1.17.4
- autobuilt fb8131a

* Tue Apr 28 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-9.dev.rhaos4.4.gitb343d63
- autobuilt b343d63

* Sat Apr 25 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-8.dev.rhaos4.4.git5f5c5e4
- autobuilt 5f5c5e4

* Sat Apr 25 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-7.dev.rhaos4.4.gitdd29309
- autobuilt dd29309

* Fri Apr 24 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-6.dev.rhaos4.4.gitb5c490c
- autobuilt b5c490c

* Fri Apr 24 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-5.dev.rhaos4.4.git1f6b245
- autobuilt 1f6b245

* Fri Apr 24 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-4.dev.rhaos4.4.gita466717
- autobuilt a466717

* Thu Apr 23 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-3.dev.rhaos4.4.gitaa2b0e8
- autobuilt aa2b0e8

* Sat Apr 18 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.4-2.dev.rhaos4.4.gitfe61deb
- bump to 1.17.4
- autobuilt fe61deb

* Fri Apr 17 2020 Lokesh Mandvekar <lsm5+bot@redhat.com> - 1.17.3-2.dev.rhaos4.4.git406d837
- re-enable autobuilder

* Thu Apr 09 2020 Jindrich Novy <jnovy@redhat.com> - 1.17.3-1.rhaos4.4
- update to https://github.com/cri-o/cri-o/releases/tag/v1.17.3
- simplify package NVR and delivery
- Resolves: #1821511

* Tue Mar 10 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.0-9.dev.rhaos4.4.gitdfc8414
- autobuilt dfc8414

* Sun Mar 08 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.0-8.dev.rhaos4.4.git36920a5
- autobuilt 36920a5

* Sat Mar 07 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.0-7.dev.rhaos4.4.gitdb5e625
- autobuilt db5e625

* Fri Mar 06 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.0-6.dev.rhaos4.4.gitdd5a702
- autobuilt dd5a702

* Fri Feb 21 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.0-5.dev.rhaos4.4.git186c230
- autobuilt 186c230

* Thu Feb 13 2020 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.17.0-4.dev.rhaos4.4.gitc3436cc
- enable debuginfo

* Thu Feb 13 2020 Jindrich Novy <jnovy@redhat.com> - 1.17.0-3.dev.rhaos4.4.gitc3436cc
- fix "Pods become unable to recover after cri-o daemon restarted."
- Resolves: #1793420

* Wed Feb 12 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.17.0-2.dev.rhaos4.4.gitc3436cc
- autobuilt c3436cc

* Mon Feb 10 2020 Lokesh Mandvekar <lsm5@redhat.com> - 1.17.0-1.dev.rhaos4.4.git3afd333
- built 3afd333
- RE: #1794191

* Wed Jan 22 2020 Jindrich Novy <jnovy@redhat.com> - 1.17.0-0.3.rc1.rhaos4.4.git5842752
- - update to 5842752

* Tue Jan 14 2020 Jindrich Novy <jnovy@redhat.com> - 1.17.0-0.2.rc1.rhaos4.4.gitb89a5fc
- update to 1.17.0-rc1

* Wed Jan 08 2020 Lokesh Mandvekar <lsm5@redhat.com> - 1.17.0-0.1.dev.rhaos4.4.git95e6452
- build release-1.17

* Tue Jan 07 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.16.2-4.dev.rhaos4.3.git639f39b
- autobuilt 639f39b

* Mon Jan 06 2020 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.16.2-3.dev.rhaos4.3.gitcccde39
- autobuilt cccde39

* Thu Dec 19 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.16.2-2.dev.rhaos4.3.git7ebd1fe
- bump to 1.16.2
- autobuilt 7ebd1fe

* Thu Dec 19 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com>
- bump to 1.15.1
- autobuilt 

* Mon Dec 16 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.16.2-4.dev.rhaos4.3.git7ebd1fe
- autobuilt 7ebd1fe

* Sat Dec 14 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.16.2-3.dev.rhaos4.3.gitd575ff8
- autobuilt d575ff8

* Fri Dec 13 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.16.2-2.dev.rhaos4.3.git8c26c5d
- bump to 1.16.2
- autobuilt 8c26c5d

* Fri Dec 13 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.16.1-8.dev.rhaos4.3.gitcee3d66
- autobuilt cee3d66

* Thu Dec 12 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.16.1-7.dev.rhaos4.3.gitfe74f76
- autobuilt fe74f76

* Thu Dec 12 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.16.1-6.dev.rhaos4.3.gitfa42e2f
- autobuilt fa42e2f

* Wed Dec 11 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.16.1-5.dev.rhaos4.3.git0c5c314
- autobuilt 0c5c314

* Tue Dec 10 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.16.1-4.dev.rhaos4.3.git16beb92
- autobuilt 16beb92

* Mon Dec 09 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.16.1-3.dev.rhaos4.3.git7b04b62
- add additional dirs

* Thu Dec 05 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.16.1-2.dev.rhaos4.3.git7b04b62
- autobuilt 7b04b62

* Mon Dec 02 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.16.1-1.dev.rhaos4.3.git356cd12
- bump to v1.16.1
- built commit 356cd12

* Wed Nov 13 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.16.0-2.rhaos4.3.git8b6bfb5
- built commit 8b6bfb5

* Fri Nov 08 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.16.0-1.rhaos4.3
- bump to v1.16.0
- built with libtrust_openssl tag

* Fri Nov 01 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.16.0-0.6.dev.rhaos4.3.git9ad059b
- build with no_openssl

* Thu Oct 31 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.16.0-0.5.dev.rhaos4.3.git9ad059b
- built commit 9ad059b
- BR: golang >= 1.12.12-4
- update other runtime deps built with golang >= 1.12.12-4

* Wed Oct 30 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.16.0-0.4.dev.rhaos4.3.giteed6aa1
- built commit eed6aa1

* Thu Oct 24 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.16.0-0.3.dev.rhaos4.3.gita1639b5
- remove unnecessary crio-wipe related stuff

* Thu Oct 24 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.16.0-0.2.dev.rhaos4.3.gita1639b5
- Resolves: #1765120 - install /etc/crio/seccomp.json

* Tue Oct 22 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.16.0-0.1.dev.rhaos4.3.gita1639b5
- bump to v1.16.0-rc2
- built release-1.16 commit a1639b5

* Wed Sep 18 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.14.10-0.18.dev.rhaos4.2.git3725006
- autobuilt 3725006
- CVE-2019-10214 patch merged upstream

* Tue Sep 17 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.14.10-0.17.dev.rhaos4.2.gitef5174f
- autobuilt ef5174f

* Tue Sep 17 2019 Jindrich Novy <jnovy@redhat.com> - 1.14.10-0.16.dev.rhaos4.2.git88978e5
- Use autosetup macro again.

* Mon Sep 16 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.14.10-0.15.dev.rhaos4.2.git88978e5
- autobuilt 88978e5

* Thu Sep 12 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.14.10-0.14.dev.rhaos4.2.git2b62abc
- autobuilt 2b62abc

* Thu Sep 12 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.14.10-0.13.dev.rhaos4.2.git6ea7d71
- autobuilt 6ea7d71

* Thu Sep 12 2019 Jindrich Novy <jnovy@redhat.com> - 1.14.10-0.12.dev.rhaos4.2.git819260a
- Fix CVE-2019-10214.

* Mon Sep 09 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.14.10-0.11.dev.rhaos4.2.git819260a
- autobuilt 819260a

* Thu Sep 05 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.14.10-0.10.dev.rhaos4.2.git458a99d
- autobuilt 458a99d

* Wed Sep 04 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.14.10-0.9.dev.rhaos4.2.gited8e23b
- autobuilt ed8e23b

* Mon Aug 26 2019 Lokesh Mandvekar (Bot) <lsm5+bot@redhat.com> - 1.14.10-0.8.dev.rhaos4.2.gitaf00350
- autobuilt af00350

* Wed Aug 07 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.14.10-0.7.dev.rhaos4.2.git7e863dd
- RE: #1731370 - disable fips mode

* Mon Aug 05 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.14.10-0.6.dev.rhaos4.2.git7e863dd
- autobuilt 7e863dd

* Sun Jul 28 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.14.10-0.5.dev.rhaos4.2.gitcf4220b
- autobuilt cf4220b

* Thu Jul 25 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.14.10-0.4.dev.rhaos4.2.git6262634
- autobuilt 6262634

* Wed Jul 24 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.14.10-0.3.dev.rhaos4.2.gitb5c74ef
- autobuilt b5c74ef

* Tue Jul 23 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.14.10-0.2.dev.rhaos4.2.git381fefe
- autobuilt 381fefe

* Mon Jul 22 2019 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.14.10-0.1.rhaos4.2
- bump to 1.14.10
- autobuilt 9a086b6

* Wed Jul 17 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.14.8-2.rhaos4.2
- crio.service requires,after crio-wipe.service
- update paths in crio-wipe unitfile

* Tue Jul 16 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.14.8-1.rhaos4.2
- bump to v1.14.8

* Thu Jul 11 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.14.7-1.rhaos4.2
- bump to v1.14.7
- changes for crio-wipe

* Wed Jul 03 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.14.6-1.rhaos4.2
- Resolves: #1726326
- bump to v1.14.6

* Wed Jun 26 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.14.5-1.rhaos4.2
- bump to v1.14.5

* Thu Jun 13 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.14.4-1.rhaos4.2
- bump to v1.14.4

* Mon May 20 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.14.1-1.rhaos4.2.gitb7644f6
- bump to v1.14.1

* Fri May 03 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.13.9-1.rhaos4.1.gitd70609a
- bump to v1.13.9

* Thu May 02 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.13.8-1.rhaos4.1.gitcf3aa64
- bump to v1.13.8

* Tue Apr 30 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.13.7-1.rhaos4.1.git4258573
- bump to v1.13.7

* Wed Apr 17 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.13.6-4.rhaos4.1.gita4b40b7
- built v1.13.6 tag

* Wed Apr 17 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.13.6-3.dev.rhaos4.1.gitee2e748
- fix the runc dep correctly this time

* Tue Apr 16 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.13.6-2.dev.rhaos4.1.gitee2e748
- requires: runc >= 1.0.0-56

* Thu Apr 11 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.13.6-1.dev.rhaos4.1.gitee2e748
- Resolves: #1698253
- bump to v1.13.6-dev
- built cri-o release-1.13 commit ee2e748

* Tue Apr 09 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.13.5-1.rhaos4.1.gita9d8dde
- Resolves: #1695516, #1698253
- bump to v1.13.5

* Mon Apr 08 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.13.4-3.rhaos4.1.git30006b3
- include 4 sysconfig files (3 old + 1 new) for backward compatibility
- 1.13.4-2 broke backward compatiblity

* Wed Mar 27 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.13.4-1.rhaos4.1.git30006b3
- bump to v1.13.4

* Wed Feb 27 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.13.1-1.rhaos4.1.git2ac1ec7
- bump to v1.13.1

* Fri Feb 22 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.13.0-1.rhaos4.1.gite8a2525
- first build for OCP 4.1

* Wed Feb 20 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.6-1.rhaos4.0.git2f0cb0d
- bump to v1.12.6
- built commit 2f0cb0d

* Tue Feb 12 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.5-6.rhaos4.0.git80d1487
- built commit 80d1487 - v1.12.5

* Sun Feb 03 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.5-5.rhaos4.0.git9076a33
- fix runc dep nvr

* Sat Feb 02 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.5-4.rhaos4.0.git9076a33
- update min runc dep (RE: #1666358)

* Sat Feb 02 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.5-3.rhaos4.0.git9076a33
- built release-1.12 branch commit 9076a33

* Wed Jan 30 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.5-2.rhaos4.0.gitd4191df
- built release-1.12 branch commit d4191df

* Tue Jan 29 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.5-1.rhaos4.0.git97ebf9b
- bump to v1.12.5-dev
- built release-1.12 branch commit 97ebf9b

* Thu Jan 24 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.4-5.rhaos4.0.git8ecb249
- fix crio-metrics sysconfig file

* Mon Jan 21 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.4-4.rhaos4.0.git8ecb249
- enable metrics
- From: Antonio Murdaca <runcom@redhat.com>

* Wed Jan 16 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.4-3.rhaos4.0.git8ecb249
- display build info in `crio --version`

* Mon Jan 07 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.4-2.rhaos4.0.git8ecb249
- update go build env

* Mon Jan 07 2019 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.4-1.rhaos4.0.git8ecb249
- bump to v1.12.4

* Thu Oct 25 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.0-3.rhaos4.0.git774a29e
- release tag reflects rhaos version

* Thu Oct 25 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.0-2.git774a29e
- build for all available arches

* Thu Oct 25 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1.12.0-1.git774a29e
- bump to v1.12.0

* Fri Oct 19 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1.11.7-1.rhaos3.11.git17bfe63
- bump to v1.11.7
- built commit 17bfe63

* Fri Sep 28 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1.11.6-1.rhaos3.11.git2d0f8c7
- bump to v1.11.6
- built commit 2d0f8c7

* Thu Sep 20 2018 Frantisek Kluknavsky <fkluknav@redhat.com> - 1.11.5-2.rhaos3.11.git1c8a4b1
- rebuilt

* Fri Sep 14 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1.11.4-2.rhaos3.11.gite0c89d8
- update crio.conf default settings

* Fri Sep 14 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1.11.4-1.rhaos3.11.gite0c89d8
- bump to v1.11.4
- epoch not needed for rhel

* Tue Sep 11 2018 Frantisek Kluknavsky <fkluknav@redhat.com> - 2:1.11.3-2.rhaos3.11.git4fbb022
- rebase

* Fri Aug 17 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.11.2-1.rhaos3.11.git3eac3b2
- bump to v1.11.2

* Wed Jul 11 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.11.1-2.rhaos3.11.git1759204
- Fix version of commit

* Tue Jul 10 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.11.1-1.rhaos3.11.git76a48bd
- bump to v1.11.1

* Mon Jul 2 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.11.0-1.rhaos3.11.git441bd3d
- bump to v1.11.0

* Mon Jul 2 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.10.5-1.rhaos3.10.git
- bump to v1.10.5

* Wed Jun 27 2018 Lokesh Mandvekar <lsm5@redhat.com> - 2:1.10.4-1.rhaos3.10.gitebaa77a
- bump to v1.10.4
- remove devel and unittest subpackages - unused
- debuginfo disabled for now, complains about %%files being empty

* Mon Jun 18 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.10.3-1.rhaos3.10.gite558bd
- bump to v1.10.3

* Tue Jun 12 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.10.2-2.rhaos3.10.git1ffcbb
- Released version of v1.10.2

* Tue May 15 2018 Lokesh Mandvekar <lsm5@redhat.com> - 2:1.10.2-1.rhaos3.10.git095e88c
- bump to v1.10.2
- built commit 095e88c
- include rhaos3.10 in release tag
- do not compress debuginfo with dwz to support delve debugger

* Tue May 8 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.10.1-2.git728df92
- bump to v1.10.1

* Wed Mar 28 2018 Lokesh Mandvekar <lsm5@redhat.com> - 2:1.10.0-1.beta.1gitc956614
- bump to v1.10.0-beta.1
- built commit c956614

* Tue Mar 13 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.9.10-1.git8723732
- bump to v1.9.10

* Fri Mar 09 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.9.9-1.git4d7e7dc
- bump to v1.9.9

* Fri Feb 23 2018 Lokesh Mandvekar <lsm5@redhat.com> - 2:1.9.8-1.git7d9d2aa
- bump to v1.9.8

* Fri Feb 23 2018 Lokesh Mandvekar <lsm5@redhat.com> - 2:1.9.7-2.gita98f9c9
- correct version in previous changelog entry

* Fri Feb 23 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.9.7-1.gita98f9c9
- Merge pull request #1357 from runcom/netns-fixes
- sandbox_stop: close/remove the netns _after_ stopping the containers
- sandbox net: set netns closed after actaully closing it

* Wed Feb 21 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.9.6-1.git5e48c92
- vendor: update c/image to handle text/plain from registries

* Fri Feb 16 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.9.5-1.git125ec8a
- image: Add lock around image cache access

* Thu Feb 15 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.9.4-1.git28c7dee
- imageService: cache information about images
- container_create: correctly set user
- system container: add /var/tmp as RW

* Sun Feb 11 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.9.3-1.git63ea1dd
- Update containers/image and containers/storage
-   Pick up lots of fixes in image and storage library

* Thu Feb 8 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.9.2-1.gitb066a83
- sandbox: fix sandbox logPath when crio restarts
- syscontainers, rhel: add ADDTL_MOUNTS
- Adapt to recent containers/image API updates
- container_create: only bind mount /etc/hosts if not provided by k8s

* Wed Jan 24 2018 Dan Walsh <dwalsh@redhat.com> - 2:1.9.1-1.gitb066a8
- Final Release 1.9.1

* Wed Jan 03 2018 Frantisek Kluknavsky <fkluknav@redhat.com> - 2:1.8.4-4.gitdffb5c2
- epoch not needed, 1.9 was never shipped, 1.8 with epoch also never shipped

* Wed Jan 03 2018 Frantisek Kluknavsky <fkluknav@redhat.com> - 2:1.8.4-3.gitdffb5c2
- reversed to 1.8, epoch

* Mon Dec 18 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1.9.0-1.git814c6ab
- bump to v1.9.0

* Fri Dec 15 2017 Dan Walsh <dwalsh@redhat.com> - 1.8.4-1.gitdffb5c2
- bump to v1.8.4

* Wed Nov 29 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1.8.2-1.git3de7ab4
- bump to v1.8.2

* Mon Nov 20 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1.8.0-1.git80f54bc
- bump to v1.8.0

* Wed Nov 15 2017 Dan Walsh <dwalsh@redhat.com> - 1.0.4-2.git4aceedee
- Fix script error in kpod completions.

* Mon Nov 13 2017 Dan Walsh <dwalsh@redhat.com> - 1.0.4-1.git4aceedee
- bump to v1.0.4
- Add crictl.yaml
- Add prometheous end points
- Several bug fixes

* Fri Nov 10 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1.0.3-1.git17bcfb4
- bump to v1.0.3

* Fri Nov 03 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1.0.2-3.git748bc46
- enable debuginfo for C binaries

* Fri Nov 03 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1.0.2-2.git748bc46
- enable debuginfo

* Mon Oct 30 2017 Dan Walsh <dwalsh@redhat.com> - 1.0.2-1.git748bc46
- Lots of bug fixes
- Fixes to pass cri-tools tests

* Wed Oct 25 2017 Dan Walsh <dwalsh@redhat.com> - 1.0.1-1.git64a30e1
- Lots of bug fixes
- Fixes to pass cri-tools tests

* Thu Oct 19 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1.0.0-7.gita636972
- update dep NVRs
- update release tag

* Mon Oct 16 2017 Dan Walsh <dwalsh@redhat.com> - 1.0.0-6.gita636972
- Get the correct checksum
- Setup storage-opt to override kernel check

* Fri Oct 13 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1.0.0-2.gitcd1bac5
- bump to v1.0.0
- require containernetworking-plugins >= 0.5.2-3

* Wed Oct 11 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1.0.0-1.rc3.gitd2c6f64
- bump to v1.0.0-rc3

* Wed Sep 20 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1.0.0-1.rc2.git6784a66
- bump to v1.0.0-rc2

* Mon Sep 18 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1.0.0-2.rc1.gitbb1da97
- bump release tag and build for extras

* Mon Sep 18 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1.0.0-1.rc1.gitbb1da97
- bump to v1.0.0-rc1 tag
- built commit bb1da97
- use bundled deps
- disable devel package
- remove redundant meta-provides

* Thu Aug 3 2017 Dan Walsh <dwalsh@redhat.com> - 1.0.0.beta.0-1.git66d96e7
- Beta Release
-   Additional registry support
-   Daemon pids-limit support
-   cri-o daemon now supports a default pid-limit on all containers to prevent fork-bombs. This is configurable by admins through a flag or /etc/crio/crio.conf
-   Configurable image volume support
-   Bugs and Stability fixes
-   OCI 1.0 runtime support
-     Dropped internal runc, and now use systems runc 

* Fri Jun 30 2017 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.0.alpha.0-1.git91977d3
- built commit 91977d3
- remove cri-o-cni subpackage
- require containernetworking-plugins >= 0.5.2-2 (same as containernetworking-cni)

* Fri Jun 23 2017 Antonio Murdaca <runcom@fedoraproject.org> - 1.0.0.alpha.0-0.git5dcbdc0.3
- rebuilt to include cri-o-cni sub package

* Wed Jun 21 2017 Antonio Murdaca <runcom@fedoraproject.org> - 1.0.0.alpha.0-0.git5dcbdc0.2
- rebuilt for s390x

* Wed Jun 21 2017 Antonio Murdaca <runcom@fedoraproject.org> - 1.0.0.alpha.0-0.git5dcbdc0.1
- built first alpha release

* Fri May 5 2017 Dan Walsh <dwalsh@redhat.com> 0.3-0.gitf648cd6e
- Bump up version to 0.3

* Tue Mar 21 2017 Dan Walsh <dwalsh@redhat.com> 0.2-1.git7d7570e
- Bump up version to 0.2

* Tue Mar 21 2017 Dan Walsh <dwalsh@redhat.com> 0.1-1.git9bf26b5
- Bump up version to 0.1

* Mon Feb 13 2017 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0-0.15.git0639f06
- built commit 0639f06
- packaging workarounds for 'go install'

* Wed Feb 8 2017 Dan Walsh <dwalsh@redhat.com> 0-0.14.git6bd7c53
- Use newer versions of runc
- Applying k8s kubelet v3 api to cri-o server
- Applying k8s.io v3 API for ocic and ocid
- doc: Add instruction to run cri-o with kubernetes
- Lots of  updates of container/storage and containers/image

* Mon Jan 23 2017 Peter Robinson <pbrobinson@fedoraproject.org> 0-0.13.git7cc8492
- Build on all kubernetes arches

* Fri Jan 20 2017 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0-0.12.git7cc8492
- add bash completion
- From: Daniel J Walsh <dwalsh@redhat.com>

* Thu Jan 19 2017 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0-0.11.git7cc8492
- remove trailing whitespace from unitfile

* Thu Jan 19 2017 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0-0.10.git7cc8492
- built commit 7cc8492
- packaging fixes from Nalin Dahyabhai <nalin@redhat.com>

* Thu Jan 19 2017 Dan Walsh <dwalsh@redhat.com> - 0-0.9.gitb9dc097
- Change to require skopeo-containers
- Merge Nalind/storage patch
-    Now uses Storage for Image Management

* Mon Jan 16 2017 Lokesh Manvekar <lsm5@fedoraproject.org> - 0-0.8.git2e6070f
- packaging changes from Nalin Dahyabhai <nalin@redhat.com>
- Don't make the ExecReload setting part of the ExecStart setting.
- Create ocid.conf in install, not in check.
- Own /etc/ocid.
- Install an "anything goes" pulling policy for a default.

* Thu Dec 22 2016 Dan Walsh <dwalsh@redhat.com> - 0-0.7.git2e6070f
- Switch locate to /var/lib/containers for images

* Thu Dec 22 2016 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0-0.6.git2e6070f
- built commit 2e6070f

* Wed Dec 21 2016 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0-0.5.git36dfef5
- install plugins into /usr/libexec/ocid/cni/
- require runc >= 1.0.0 rc2

* Wed Dec 21 2016 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0-0.4.git36dfef5
- built runcom/alpha commit 36dfef5
- cni bundled for now

* Thu Dec 15 2016 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0-0.3.gitc57530e
- Resolves: #1392977 - first upload to Fedora
- add build deps, enable only for x86_64 (doesn't build on i686)

* Thu Dec 15 2016 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0-0.2.gitc57530e
- add Godeps.json

* Tue Nov 08 2016 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0-0.1.gitc57530e
- First package for Fedora


